@@ -10,12 +10,12 @@ use lib qw(../lib);
 {
 	package Runner;
 	use Moose;
-	extends 'Reflex::Object';
+	extends 'Reflex::Base';
 	use Reflex::POE::Wheel::Run;
-	use Reflex::Trait::Observer;
+	use Reflex::Trait::Observed;
 
 	has child => (
-		traits  => ['Reflex::Trait::Observer'],
+		traits  => ['Reflex::Trait::Observed'],
 		isa     => 'Maybe[Reflex::POE::Wheel::Run]',
 		is      => 'rw',
 	);
@@ -67,5 +67,5 @@ use lib qw(../lib);
 # Main.
 
 my $runner = Runner->new();
-Reflex::Object->run_all();
+Reflex->run_all();
 exit;
